@@ -21,7 +21,7 @@ from chakin.io import warn
 
 from future import standard_library
 
-from sqlalchemy import Column, Float, ForeignKey, Integer, String, Table
+from sqlalchemy import Column, Float, ForeignKey, Integer, String, Table, inspect
 from sqlalchemy import exc as sa_exc
 
 standard_library.install_aliases()
@@ -824,7 +824,7 @@ class LoadClient(Client):
             self.ci.create_cvterm(term='analysis_blast_output_iteration_hits', term_definition='Hits of a blast', cv_name='tripal', db_name='tripal')
             # Tables for blast
             added_table = False
-            if not self.engine.dialect.has_table(self.engine, 'tripal_analysis_blast', schema='public'):
+            if not inspect(self.engine).has_table('tripal_analysis_blast', schema='public'):
                 tripal_analysis_blast_table = Table(
                     'tripal_analysis_blast', self.metadata,
                     Column('db_id', Integer, primary_key=True, nullable=False, default=0, index=True),
@@ -839,7 +839,7 @@ class LoadClient(Client):
                 tripal_analysis_blast_table.create(self.engine)
                 added_table = True
 
-            if not self.engine.dialect.has_table(self.engine, 'blast_organisms', schema=self.ci.dbschema):
+            if not inspect(self.engine).has_table('blast_organisms', schema=self.ci.dbschema):
                 blast_organisms_table = Table(
                     'blast_organisms', self.metadata,
                     Column('blast_org_id', Integer, primary_key=True, nullable=False),
@@ -855,7 +855,7 @@ class LoadClient(Client):
                     self.ci._reflect_tables()
                     self.model = self.ci.model
 
-            if not self.engine.dialect.has_table(self.engine, 'blast_hit_data', schema=self.ci.dbschema):
+            if not inspect(self.engine).has_table('blast_hit_data', schema=self.ci.dbschema):
                 blast_hit_data_table = Table(
                     'blast_hit_data', self.metadata,
                     Column('analysisfeature_id', Integer, ForeignKey(self.model.analysisfeature.analysisfeature_id, ondelete="CASCADE"), nullable=False, index=True, primary_key=True),
